@@ -1,4 +1,3 @@
-from tnorm.utilities.utilities import *
 from tnorm.utilities.regina_helpers import *
 from tnorm.kernel.matrices import oriented_quads_mat, quads_mat
 
@@ -45,7 +44,8 @@ def is_embedded(qtons,TN_wrapper):
     return False
 
 
-
+def gcd(a,b):
+    return abs(GCD(a,b))
 
 
 
